@@ -303,7 +303,7 @@ def _xhj_get_history_files(sort=True, newest_first=False):
     """Find and return the history files. Optionally sort files by
     modify time.
     """
-    data_dir = builtins.__xonsh_env__.get("XONSH_DATA_DIR")
+    data_dir = builtins.__xonsh__.env.get("XONSH_DATA_DIR")
     data_dir = xt.expanduser_abs_path(data_dir)
     try:
         files = [
@@ -313,7 +313,7 @@ def _xhj_get_history_files(sort=True, newest_first=False):
         ]
     except OSError:
         files = []
-        if builtins.__xonsh_env__.get("XONSH_DEBUG"):
+        if builtins.__xonsh__.env.get("XONSH_DEBUG"):
             xt.print_exception("Could not collect xonsh history files.")
     if sort:
         files.sort(key=lambda x: os.path.getmtime(x), reverse=newest_first)
@@ -343,7 +343,7 @@ class JsonHistoryGC(threading.Thread):
     def run(self):
         while self.wait_for_shell:
             time.sleep(0.01)
-        env = builtins.__xonsh_env__  # pylint: disable=no-member
+        env = builtins.__xonsh__.env  # pylint: disable=no-member
         if self.size is None:
             hsize, units = env.get("XONSH_HISTORY_SIZE")
         else:
@@ -367,7 +367,7 @@ class JsonHistoryGC(threading.Thread):
         (timestamp, number of cmds, file name) tuples.
         """
         # pylint: disable=no-member
-        env = getattr(builtins, "__xonsh_env__", None)
+        env = getattr(builtins, "__xonsh__.env", None)
         if env is None:
             return []
         boot = uptime.boottime()
@@ -430,7 +430,7 @@ class JsonHistoryFlusher(threading.Thread):
 
     def dump(self):
         """Write the cached history to external storage."""
-        opts = builtins.__xonsh_env__.get("HISTCONTROL")
+        opts = builtins.__xonsh__.env.get("HISTCONTROL")
         last_inp = None
         cmds = []
         for cmd in self.buffer:
@@ -449,7 +449,7 @@ class JsonHistoryFlusher(threading.Thread):
         if self.at_exit:
             hist["ts"][1] = time.time()  # apply end time
             hist["locked"] = False
-        if not builtins.__xonsh_env__.get("XONSH_STORE_STDOUT", False):
+        if not builtins.__xonsh__.env.get("XONSH_STORE_STDOUT", False):
             [cmd.pop("out") for cmd in hist["cmds"][load_hist_len:] if "out" in cmd]
         with open(self.filename, "w", newline="\n") as f:
             xlj.ljdump(hist, f, sort_keys=True)
@@ -540,7 +540,7 @@ class JsonHistory(History):
         super().__init__(sessionid=sessionid, **meta)
         if filename is None:
             # pylint: disable=no-member
-            data_dir = builtins.__xonsh_env__.get("XONSH_DATA_DIR")
+            data_dir = builtins.__xonsh__.env.get("XONSH_DATA_DIR")
             data_dir = os.path.expanduser(data_dir)
             self.filename = os.path.join(
                 data_dir, "xonsh-{0}.json".format(self.sessionid)
@@ -641,7 +641,7 @@ class JsonHistory(History):
                 commands = json_file.load()["cmds"]
             except json.decoder.JSONDecodeError:
                 # file is corrupted somehow
-                if builtins.__xonsh_env__.get("XONSH_DEBUG") > 0:
+                if builtins.__xonsh__.env.get("XONSH_DEBUG") > 0:
                     msg = "xonsh history file {0!r} is not valid JSON"
                     print(msg.format(f), file=sys.stderr)
                 continue
@@ -660,7 +660,7 @@ class JsonHistory(History):
         data["length"] = len(self)
         data["buffersize"] = self.buffersize
         data["bufferlength"] = len(self.buffer)
-        envs = builtins.__xonsh_env__
+        envs = builtins.__xonsh__.env
         data["gc options"] = envs.get("XONSH_HISTORY_SIZE")
         return data
 
@@ -686,7 +686,7 @@ sqlite3 = _LazyModule.load('sqlite3', 'sqlite3')
 # amalgamated xonsh.history.base
 # amalgamated xonsh.tools
 def _xh_sqlite_get_file_name():
-    envs = builtins.__xonsh_env__
+    envs = builtins.__xonsh__.env
     file_name = envs.get("XONSH_HISTORY_SQLITE_FILE")
     if not file_name:
         data_dir = envs.get("XONSH_DATA_DIR")
@@ -824,7 +824,7 @@ class SqliteHistoryGC(threading.Thread):
         if self.size is not None:
             hsize, units = xt.to_history_tuple(self.size)
         else:
-            envs = builtins.__xonsh_env__
+            envs = builtins.__xonsh__.env
             hsize, units = envs.get("XONSH_HISTORY_SIZE")
         if units != "commands":
             print(
@@ -854,7 +854,7 @@ class SqliteHistory(History):
         self.tss = []
 
     def append(self, cmd):
-        envs = builtins.__xonsh_env__
+        envs = builtins.__xonsh__.env
         opts = envs.get("HISTCONTROL")
         inp = cmd["inp"].rstrip()
         self.inps.append(inp)
@@ -901,7 +901,7 @@ class SqliteHistory(History):
             sessionid=self.sessionid, filename=self.filename
         )
         data["all items"] = xh_sqlite_get_count(filename=self.filename)
-        envs = builtins.__xonsh_env__
+        envs = builtins.__xonsh__.env
         data["gc options"] = envs.get("XONSH_HISTORY_SIZE")
         return data
 
@@ -935,7 +935,7 @@ HISTORY_BACKENDS = {"dummy": DummyHistory, "json": JsonHistory, "sqlite": Sqlite
 
 def construct_history(**kwargs):
     """Construct the history backend object."""
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     backend = env.get("XONSH_HISTORY_BACKEND")
     if isinstance(backend, str) and backend in HISTORY_BACKENDS:
         kls_history = HISTORY_BACKENDS[backend]
@@ -955,14 +955,14 @@ def construct_history(**kwargs):
 def _xh_session_parser(hist=None, newest_first=False, **kwargs):
     """Returns history items of current session."""
     if hist is None:
-        hist = builtins.__xonsh_history__
-    return hist.items(newest_first=newest_first)
+        hist = builtins.__xonsh__.history
+    return hist.items()
 
 
 def _xh_all_parser(hist=None, newest_first=False, **kwargs):
     """Returns all history items."""
     if hist is None:
-        hist = builtins.__xonsh_history__
+        hist = builtins.__xonsh__.history
     return hist.all_items(newest_first=newest_first)
 
 
@@ -1256,7 +1256,7 @@ def _xh_create_parser():
         help="makes the gc non-blocking, and thus return sooner",
     )
 
-    hist = builtins.__xonsh_history__
+    hist = builtins.__xonsh__.history
     if isinstance(hist, JsonHistory):
         # add actions belong only to JsonHistory
         diff = subp.add_parser("diff", help="diff two xonsh history files")
@@ -1298,7 +1298,7 @@ def _xh_parse_args(args):
 
 def history_main(args=None, stdin=None, stdout=None, stderr=None):
     """This is the history command entry point."""
-    hist = builtins.__xonsh_history__
+    hist = builtins.__xonsh__.history
     ns = _xh_parse_args(args)
     if not ns or not ns.action:
         return
